handle_gpio_interrupt

Function handle_gpio_interrupt 

pub unsafe fn handle_gpio_interrupt()
Available on crate feature unstable only.
Drive the GPIO async API from a user-installed raw GPIO interrupt handler.

This is the entry point that lets users who bypass esp-hal’s GPIO ISR dispatch (typically by defining their own #[unsafe(no_mangle)] unsafe extern "C" fn GPIO(), or by registering their own handler via crate::interrupt::bind_handler) keep the GPIO async API working.

Safety

Must be called from a GPIO interrupt context.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.